//use std::io::*;

pub struct Circle {
  n: i32,
}

pub trait Info {
  fn info_new(n: i32) -> Self;
  fn even_or_odd(&self) -> String;
}

impl Info for Circle {
  fn info_new(n: i32) -> Circle {
    Circle { n: n }
  }
  fn even_or_odd(&self) -> String {
    if self.n % 2 == 0 {
      return "even".to_string();
    } else {
      return "odd".to_string();
    }
  }
}
// use checkeo::*;
fn main() {}
